=====================================
Sample Networking-MidoNet Policy File
=====================================

The following is a sample networking-midonet policy file for adaptation and use.

The sample policy can also be viewed in :download:`file form
</_static/networking-midonet.policy.yaml.sample>`.

.. important::

   The sample policy file is auto-generated from networking-midonet when this
   documentation is built. You must ensure your version of networking-midonet
   matches the version of this documentation.

.. literalinclude:: /_static/networking-midonet.policy.yaml.sample
